==> kmyfirewall_0.9.6.2.orig.tar.gz: kmyfirewall-0.9.6.2/kmyfirewall/core/kmferror.cpp <==
/***************************************************************************
                       kmferror.cpp  -  description
                          -------------------
 begin                : Tue Aug 6 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : a9806056@unet.univie.ac.at
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kmferror.h"

// QT includes
#include <qstring.h>

// KDE includes
#include <kdebug.h>

KMFError::KMFError() {
	//  kdDebug() << "Creating new KMFError Object" << endl;
	m_err_type = "";
	m_err_msg = "";
	m_err_num = -1;

}
KMFError::~KMFError() {}

void KMFError::setErrMsg( const QString &msg ) {
	m_err_msg = msg;
}

void KMFError::setErrType( const QString &type ) {
	if ( type == "OK" ) {
		m_err_type = "OK";
		m_err_msg = "OK";
		m_err_num = 0;
	} else if ( type == "HINT" ) {
		m_err_type = "HINT";
		m_err_num = 0;
	} else if ( type == "NORMAL" ) {
		m_err_type = "NORMAL";
		m_err_num = 1;
	} else if ( type == "FATAL" ) {
		m_err_type = "FATAL";
		m_err_num = 2;
	}
}

==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/core/kmferror.cpp <==
/***************************************************************************
 begin                : Tue Aug 6 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@gmail.com
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kmferror.h"

// QT includes
#include <qstring.h>

// KDE includes
#include <kdebug.h>

KMFError::KMFError() {
	//  kdDebug() << "Creating new KMFError Object" << endl;
	m_err_type = -1;
	m_err_msg = "";
	m_err_num = -1;

}
KMFError::~KMFError() {}

void KMFError::setErrMsg( const QString &msg ) {
	m_err_msg = msg;
}

void KMFError::setErrType( int type  ) {
//	kdDebug() << "KMFError::setErrType( int type  ) - Setting Error Type: "  << type << endl;
	if ( type == OK ) {
		m_err_type = OK;
		m_err_num = 0;
	} else if ( type == HINT ) {
		m_err_type = HINT;
		m_err_num = 0;
	} else if ( type == NORMAL ) {
		m_err_type = NORMAL;
		m_err_num = NORMAL;
	} else if ( type == FATAL ) {
		m_err_type = FATAL;
		m_err_num = FATAL;
	}
}
